
# Petspackage_Ayan_123

It helps the user to classify according to their breeds and types

## Installing the package

pip Install

## Using the package

```import Petspackage_Ayan_123 as cute```

User has to input all the seven attributes and it returns all the information about the pet.

## Function used

fun(cuddle)